@@ -1,19 +1,15 @@
 #' @rdname detectFronts
 #' @method detectFronts RasterLayer
 #' @export
-detectFronts.RasterLayer <- function(x, qLimits = c(0.9, 0.99), finalSmooth = FALSE, intermediate = FALSE,
-                                control = list()){
+detectFronts.RasterLayer <- function(x, method = "BelkinOReilly2009", intermediate = FALSE, ...){
 
   # Extract coordinates and data for calculate fronts from Raster and convert to list
   startMatrix <- matrix(data = x@data@values, nrow = x@ncols, ncol = x@nrows)
   startMatrix <- list(x = seq(from = x@extent@xmin, to = x@extent@xmax, length.out = x@ncols),
                       y = seq(from = x@extent@ymin, to = x@extent@ymax, length.out = x@nrows),
                       z = startMatrix)
-                      # z = startMatrix[,seq(x@nrows, 1)])
 
-  # Apply the basic function
-  allOuts <- detectFronts.default(x = startMatrix, qLimits = qLimits, finalSmooth = finalSmooth,
-                                  intermediate = intermediate, control = control)
+  allOuts <- detectFronts(x = startMatrix, method = method, intermediate = intermediate, ...)
 
   # Depending on 'intermediate', the output will be a single Raster or a list of them
   if(isTRUE(intermediate)){
