@@ -1,4 +1,4 @@
-
+rm(list = ls()); gc(reset = TRUE)
 # Detect fronts --------------------------------------------------------------------------
 
 # Load example data
@@ -8,7 +8,7 @@ exampleSSTData <- list(x = sst$longitude,
                        z = sst$sst[,,1])
 
 # Apply detectFronts function
-out <- detectFronts(x = exampleSSTData, intermediate = TRUE, finalSmooth = TRUE)
+out <- detectFronts(x = exampleSSTData)
 str(out)
 
 # Make plots -----------------------------------------------------------------------------
@@ -29,11 +29,13 @@ axis(side = 1, at = xAxis, labels = paste(abs(xAxis), "\u00b0W"))
 axis(side = 2, at = yAxis, labels = paste(abs(yAxis), "\u00b0S"), las = 2)
 
 # Plot gradient map
+out$gradient$z <- log10(out$gradient$z)
 image(out$gradient, axes = FALSE, col = colPalette); box()
 mtext(text = "Gradient", side = 3, line = -2, adj = 0.99, cex = 1.2, font = 2)
 axis(side = 1, at = xAxis, labels = paste(abs(xAxis), "\u00b0W"))
 
 # Plot gradient with noise cleaning filter applied
+out$noise_cleared$z <- log10(out$noise_cleared$z)
 image(out$noise_cleared, axes = FALSE, col = colPalette); box()
 mtext(text = "Noise cleared", side = 3, line = -2, adj = 0.99, cex = 1.2, font = 2)
 axis(side = 1, at = xAxis, labels = paste(abs(xAxis), "\u00b0W"))
